| Home | Libraries | People | FAQ | More

#### Binomial Distribution Examples

Binomial Coin-Flipping Example
Binomial Quiz Example
Calculating Confidence Limits on the Frequency of Occurrence for a Binomial Distribution
Estimating Sample Sizes for a Binomial Distribution.

See also the reference documentation for the Binomial Distribution.

| Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)